==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Sections/language/lang-french.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PRINTER","Format imprimable");
define("_PREVIOUS","Page Pr&eacute;c&eacute;dente");
define("_NEXT","Page Suivante");

define("_COMESFROM","Cet article provient de");
define("_THEURL","L'URL de cet article est:");
define("_SECWELCOME","Bienvenue dans la Rubrique Sp&eacute;ciale de");
define("_YOUCANFIND","Vous trouverez ici quelques articles cools non pr&eacute;sent&eacute;s sur la page d'acceuil.");
define("_THISISSEC","Ceci est la rubrique");
define("_FOLLOWINGART","Suivre les articles &eacute;dit&eacute;s sous cette rubrique.");
define("_SECRETURN","Retour &agrave; l'index des rubriques");
define("_TOTALWORDS","total des mots dans ce texte");
define("_BACKTO","Retour");
define("_SECINDEX","Index des Rubriques");
define("_PAGE","Page");


?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Sections/language/lang-french.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PRINTER","Format imprimable");
define("_PREVIOUS","Page Pr&eacute;c&eacute;dente");
define("_NEXT","Page Suivante");

define("_COMESFROM","Cet article provient de");
define("_THEURL","L'URL de cet article est:");
define("_SECWELCOME","Bienvenue dans la Rubrique Sp&eacute;ciale de");
define("_YOUCANFIND","Vous trouverez ici quelques articles cools non pr&eacute;sent&eacute;s sur la page d'acceuil.");
define("_THISISSEC","Ceci est la rubrique");
define("_FOLLOWINGART","Suivre les articles &eacute;dit&eacute;s sous cette rubrique.");
define("_SECRETURN","Retour &agrave; l'index des rubriques");
define("_TOTALWORDS","total des mots dans ce texte");
define("_BACKTO","Retour");
define("_SECINDEX","Index des Rubriques");
define("_PAGE","Page");


?>
